# NiceGui tips and tricks

![tag](python)

## projet todo

projet todo qui utilise nicegui et les api en interne

http://github.com/fraoustin/todo

![](./upload/todo.png)

l'idée est d'utiliser les schemas des api dans les schema du ui (qui appelle les api en interne)

On utilise aussi des tests (via unittest) et une configuration via des fichier.env

## affichage mobile / bureau

```python
desktop_button = ui.button('Bouton Desktop').props('flat')  # start hidden
mobile_button = ui.button('Bouton Mobile').props('flat')
desktop_button._props['data-id'] = 'desktop-btn'
mobile_button._props['data-id'] = 'mobile-btn'
ui.button('Bouton Mobile Solution par classe').props('flat').classes('lg:hidden')

# Injecter un JS qui détecte la taille
ui.add_body_html('''
    <script>
    function updateView() {
        const isDesktop = window.innerWidth >= 1024;
        const desktopBtn = document.querySelector('[data-id="desktop-btn"]');
        const mobileBtn = document.querySelector('[data-id="mobile-btn"]');
        if (desktopBtn && mobileBtn) {
            desktopBtn.style.display = isDesktop ? 'inline-block' : 'none';
            mobileBtn.style.display = isDesktop ? 'none' : 'inline-block';
        }
    }
    window.addEventListener('resize', updateView);
    window.addEventListener('load', updateView);
    </script>
    ''')
```

## input avec boutton

```python
class ButtonForInput(ui.button):

    def __init__(self, input, *args, **kw):
        ui.button.__init__(self, *args, **kw)
        self._input = input
    
    @property
    def value(self):
        return self._input.value
    
    def set_value(self, value):
        self._input.value = value


class InputWithButton(ui.input):

    def __init__(self, icon, *args, **kw):
        ui.input.__init__(self, *args, **kw)
        with self.classes('text-body1 flex-grow').props('borderless') as inputbox:
            self._button = ButtonForInput(inputbox, icon=icon).classes('text-h5').props('flat dense').bind_visibility_from(inputbox, 'value')

    def on(self, action, dest, *args, **kw):
        ui.input.on(self, action, dest, *args, **kw)
        if action == 'keydown.enter':
            self._button.on('click', dest)



with ui.row().classes('w-full no-wrap items-center').style('max-width: 768px;margin: auto;'):
	InputWithButton(icon='o_arrow_circle_up', placeholder='Message pour IA').on('keydown.enter', send)
```

## boutton avec tooltip

```python
        with ui.button( icon='o_comment').props('flat round'):
            Tooltip('nouveau chat')
```

## panneau de gauche fin en bureau, normal en mobile

```python
    with ui.left_drawer(top_corner=True, bottom_corner=True).style('overflow: hidden;white-space: nowrap').props('bordered').props('width') as left_drawer:
        with ui.row().classes('items-center'):
            ui.icon("checklist").classes('text-2xl') 
            ui.label("Todo").classes('lg:hidden')
        
        with ui.list().classes('flex-grow w-full'):
            pass        
        with ui.list().classes('flex-grow w-full').classes('lg:hidden').style('width: 80vw'):
            pass
        with ui.list().classes('w-full'):
            with ui.row().classes('items-center cursor-pointer'):
                ui.icon("settings").classes('text-2xl') 
                ui.label("parametrage").classes('lg:hidden')
    ui.button(on_click=lambda: (left_drawer.show(), ), icon='checklist').props('flat round').classes('lg:hidden')
```